@@ -95,7 +95,9 @@ class ClientUserMaker(BaseClientAuthMaker):
     mod_schema = dict(
         type="object",
         additionalProperties=False,
-        properties = dict(),
+        properties=dict(
+            name=dict(type="string", minLength=1, pattern="^[a-zA-Z][a-zA-Z0-9_]*$")
+        ),
         #required=[],
     )
     name = None
@@ -131,13 +133,13 @@ class ClientUserMaker(BaseClientAuthMaker):
     async def send(self, client: Client, _kind="user"):
         """Send a record representing this user to the server."""
         async with client._stream(
-            action="auth_set", typ=type(self)._auth_method, kind=_kind, stream=True
+            action="auth_set", typ=type(self)._auth_method, kind=_kind, ident=self.ident, stream=True
         ) as s:
             # we could initially send the ident but don't here, for testing
             m = await s.recv()
             assert m.step == "GiveName", m
             await s.send(
-                step="HasName", name=self.name, chain=self._chain, aux=self._aux
+                step="HasName", name=self.name, chain=self._chain
             )
             m = await s.recv()
             assert m.chain.prev is None
