@@ -151,7 +151,7 @@ class NodeFinder:
             # so that they can match multiple entries.
         #if not steps:
         #    raise KeyError(name)
-        if steps and new:
+        if new:
             return type(self)(steps, **self.copy_args)
         else:
             self.steps = steps
@@ -438,7 +438,7 @@ class AclEntry(MetaEntry):
 AclEntry.SUBTYPE = AclEntry
 
 
-class AclName(MetaPathEntry):
+class AclName(AclEntry):
     """I am a named tree for ACL entries.
     """
 
@@ -450,10 +450,6 @@ class AclName(MetaPathEntry):
             return None
         return typ in acl.value
 
-    async def set(self, value):
-        if value is not None:
-            raise ValueError("This node can't have data.")
-
 
 class AclRoot(MetaEntry):
     SUBTYPE = AclName
